@@ -82,7 +82,7 @@ int check_bankData_lookup(unsigned long tries = 5)
 int check_testkontos(const std::string& filename)
 {
    assert(filename.size()>0);
-   AccountNumberCheck checker("../bankdata/bankdata.txt");
+   AccountNumberCheck checker(filename);
    AccountNumberCheck::Result res;
    char blz[20],kto[20],method[200],info[200];
    FILE *istr = fopen(filename.c_str(), "r");
@@ -102,12 +102,12 @@ int main(int argc, char **argv) {
    if (argc > 1)
       tries = atol(argv[1]);
    check_bankData_lookup(tries);
-   
-//    std::string filename;
-//    if (argc > 1)
-//       filename = argv[1];
-//    check_testkontos(filename);
-   
+
+    std::string filename;
+    if (argc > 2)
+       filename = argv[2];
+    check_testkontos(filename);
+
    return 0;
 }
 
