@@ -37,6 +37,7 @@
 #endif
 #include "ktoblzcheck.h"
 #include <assert.h>
+#include <string.h> // for strdup()
 
 
 AccountNumberCheck *AccountNumberCheck_new()
@@ -133,3 +134,9 @@ const char* AccountNumberCheck_libraryVersion()
 {
   return AccountNumberCheck::libraryVersion();
 }
+
+char* AccountNumberCheck_bankdata_dir()
+{
+  return strdup(AccountNumberCheck::bankdata_dir().c_str());
+}
+
